@@ -1,4 +1,4 @@
-use Test::More;
+use Test::More tests => 12;
 
 use FindBin;
 use lib "$FindBin::Bin";
@@ -30,7 +30,8 @@ BEGIN { ::use_ok('filtered', by => 'MyFilter', as => 'FilteredTest', on => 'Filt
 BEGIN { ::use_ok('filtered', by => 'MyFilter', as => 'FilteredTest', @arg, 'FilterTest', 'call'); }
 
 ::is(call(), 'BARBARBAR');
-::is(FilteredTest::ppi_check(), $USE_PPI ? 'FilterTest::Module' : 'FilteredTest::Module');
+::is(FilteredTest::ppi_check(), $USE_PPI ? 'Dummy::FilterTest::Module' : 'Dummy::FilteredTest::Module');
+::is(FilteredTest::ppi_check_old(), 'FilteredTest::Module');
 
 package b;
 
@@ -49,6 +50,6 @@ BEGIN { ::use_ok('filtered', by => 'MyFilter2', as => 'FilteredTest3', on => 'Fi
 package d;
 
 # Different target should be available
-BEGIN { ::use_ok('filtered', by => 'MyFilter2', @arg, 'FilterTest3', 'call'); }
+BEGIN { ::use_ok('filtered', by => 'MyFilter2', @arg, 'Test::Test::FilterTest3', 'call'); }
 
 ::is(call(), 'BARZOTZOT');
